@@ -1,4 +1,7 @@
 skip_unless_has_test_db <- function(expr) {
+  if (!identical(Sys.getenv("NOT_CRAN"), "true")) {
+    return(skip("On CRAN"))
+  }
   tryCatch({
     DBItest:::connect(expr)
     TRUE
